{% load i18n %}<b>{% trans 'Thank you for your order!' %}</b>
{% trans 'Your order' %} #{{ order.id }} {% trans 'from' %} {{ order.created|date:'d E Y' }}
{% trans 'successfully accepted.' %}
{% trans 'We will get back to you shortly.' %}
{% trans 'Thank you for being with us.' %}

